# eric7.Plugins.UiExtensionPlugins.Translator.TranslatorLanguagesDb

Module implementing the translation languages database.

### Global Attributes

None

### Classes

TranslatorLanguagesDb | Class implementing the translation languages database.

### Functions

None

## TranslatorLanguagesDb

Class implementing the translation languages database.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

TranslatorLanguagesDb | Constructor
convertTwoToThree | Public method to convert a two character language code to a thre character code.
getAllLanguages | Public method to get a list of the supported language codes.
getLanguage | Public method to get a translated language.
getLanguageIcon | Public method to get a language icon.

### Static Methods

None

#### TranslatorLanguagesDb (Constructor)

TranslatorLanguagesDb(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### TranslatorLanguagesDb.convertTwoToThree

convertTwoToThree(code)

Public method to convert a two character language code to a thre character code.

code (str)
  two character language code

Return:
  three character language code

Return Type:
  str

#### TranslatorLanguagesDb.getAllLanguages

getAllLanguages()

Public method to get a list of the supported language codes.

Return:
  list of supported language codes

Return Type:
  list of str

#### TranslatorLanguagesDb.getLanguage

getLanguage(code)

Public method to get a translated language.

code (str)
  language code

Return:
  translated language

Return Type:
  str

#### TranslatorLanguagesDb.getLanguageIcon

getLanguageIcon(code)

Public method to get a language icon.

code (str)
  language code

Return:
  language icon

Return Type:
  QIcon

Up